/*
 * ################################################################
 *
 * ProActive Parallel Suite(TM): The Java(TM) library for
 *    Parallel, Distributed, Multi-Core Computing for
 *    Enterprise Grids & Clouds
 *
 * Copyright (C) 1997-2011 INRIA/University of
 *                 Nice-Sophia Antipolis/ActiveEon
 * Contact: proactive@ow2.org or contact@activeeon.com
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Affero General Public License
 * as published by the Free Software Foundation; version 3 of
 * the License.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * If needed, contact us to obtain a release under GPL Version 2 or 3
 * or a different license than the AGPL.
 *
 *  Initial developer(s):               The ActiveEon Team
 *                        http://www.activeeon.com/
 *  Contributor(s):
 *
 * ################################################################
 * $$ACTIVEEON_INITIAL_DEV$$
 */
package org.ow2.proactive.virtualizing.core;

import org.ow2.proactive.virtualizing.core.error.VirtualServiceException;


/**
 * This interface represents a virtual machine from any 
 * virtualization software. This is a minimal class that only 
 * allows you to power on/off a virtual machine. If you want to take advantage of
 * extra features offered by a class that implements {@link VirtualMachine},
 * please refer directly to that class.
 *
 */
public interface VirtualMachine {

    /**
     * To power this virtual machine on.
     * @return true in case of success, false otherwise.
     * @throws VirtualServiceException if an issue occurs.
     */
    public boolean powerOn() throws VirtualServiceException;

    /**
     * Powers the VM off.
     * @return true in case of success, false otherwise.
     * @throws VirtualServiceException
     */
    public boolean powerOff() throws VirtualServiceException;

    /*---------------------------------
     * Getters & Setters
     *--------------------------------*/

    /**
     * This method returns the running state of this virtual machine.
     */
    public State getState() throws VirtualServiceException;

    public String getName() throws VirtualServiceException;
}
