/*
 * ################################################################
 *
 * ProActive Parallel Suite(TM): The Java(TM) library for
 *    Parallel, Distributed, Multi-Core Computing for
 *    Enterprise Grids & Clouds
 *
 * Copyright (C) 1997-2011 INRIA/University of
 *                 Nice-Sophia Antipolis/ActiveEon
 * Contact: proactive@ow2.org or contact@activeeon.com
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Affero General Public License
 * as published by the Free Software Foundation; version 3 of
 * the License.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * If needed, contact us to obtain a release under GPL Version 2 or 3
 * or a different license than the AGPL.
 *
 *  Initial developer(s):               The ActiveEon Team
 *                        http://www.activeeon.com/
 *  Contributor(s):
 *
 * ################################################################
 * $$ACTIVEEON_INITIAL_DEV$$
 */
package org.ow2.proactive.virtualizing.core;

import org.ow2.proactive.virtualizing.core.error.VirtualServiceException;


/**
 * Second version of the Virtual Machine interface.
 * Adds clone capabilities and private communication with
 * virtual machine through environment update ( write data ).
 */
public interface VirtualMachine2 extends VirtualMachine, IVMGuestStatus {

    /**
     * Clones the virtual machine.
     * @param name The clone's name.
     * @return This virtual machine's clone.
     * @throws VirtualServiceException
     */
    public VirtualMachine2 clone(String name) throws VirtualServiceException;

    /**
     * To destroy a cloned virtual machine.
     * @throws VirtualServiceException
     */
    public void destroy() throws VirtualServiceException;

    /**
     * The method must be used virtual machine powered off. Implementation must
     * ensure that the data are available once the virtual
     * machine is running
     * @param dataKey the key of the data to push within the vm's environment
     * @param value the key's value
     * @return true in case of success false otherwise
     * @throws VirtualServiceException
     */
    public boolean pushData(String dataKey, String value) throws VirtualServiceException;

    /**
     * To read a data, either set from the guest operating system or previsously set
     * using {@link #pushData(String, String)}
     * @param dataKey The key/value pair's key.
     * @return The associated key/value pair's value if it exists, null otherwise.
     * @throws VirtualServiceException
     */
    public String getData(String dataKey) throws VirtualServiceException;
}
