/*
 * ################################################################
 *
 * ProActive Parallel Suite(TM): The Java(TM) library for
 *    Parallel, Distributed, Multi-Core Computing for
 *    Enterprise Grids & Clouds
 *
 * Copyright (C) 1997-2011 INRIA/University of
 *                 Nice-Sophia Antipolis/ActiveEon
 * Contact: proactive@ow2.org or contact@activeeon.com
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Affero General Public License
 * as published by the Free Software Foundation; version 3 of
 * the License.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * If needed, contact us to obtain a release under GPL Version 2 or 3
 * or a different license than the AGPL.
 *
 *  Initial developer(s):               The ActiveEon Team
 *                        http://www.activeeon.com/
 *  Contributor(s):
 *
 * ################################################################
 * $$ACTIVEEON_INITIAL_DEV$$
 */
package org.ow2.proactive.virtualizing.core;

import java.util.ArrayList;
import java.util.Iterator;

import org.apache.log4j.Logger;
import org.ow2.proactive.virtualizing.core.error.VirtualServiceException;


/**
 * This class is intended to give you the possibility to manage
 * numerous {@link VirtualMachine} at a time.
 *
 * @param <E>
 */
public class VirtualMachineCollection<E extends VirtualMachine> extends ArrayList<E> {

    /** The class' logger */
    private static final Logger logger = Logger.getLogger(VirtualMachineCollection.class);

    /**
     * To power on all the {@link VirtualMachine} that are presents in this list.
     */
    public void startAll() {
        Iterator<? extends VirtualMachine> it = this.iterator();
        while (it.hasNext()) {
            VirtualMachine current = it.next();
            try {
                current.powerOn();
            } catch (VirtualServiceException e) {
                e.printStackTrace();
            }
        }
    }

    /**
     * To power off all the {@link VirtualMachine} that are presents in this list.
     */
    public void stopAll() {
        Iterator<? extends VirtualMachine> it = this.iterator();
        while (it.hasNext()) {
            VirtualMachine current = it.next();
            try {
                current.powerOff();
            } catch (VirtualServiceException e) {
                e.printStackTrace();
            }
        }
    }
}