/*
 * ################################################################
 *
 * ProActive Parallel Suite(TM): The Java(TM) library for
 *    Parallel, Distributed, Multi-Core Computing for
 *    Enterprise Grids & Clouds
 *
 * Copyright (C) 1997-2011 INRIA/University of
 *                 Nice-Sophia Antipolis/ActiveEon
 * Contact: proactive@ow2.org or contact@activeeon.com
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Affero General Public License
 * as published by the Free Software Foundation; version 3 of
 * the License.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * If needed, contact us to obtain a release under GPL Version 2 or 3
 * or a different license than the AGPL.
 *
 *  Initial developer(s):               The ActiveEon Team
 *                        http://www.activeeon.com/
 *  Contributor(s):
 *
 * ################################################################
 * $$ACTIVEEON_INITIAL_DEV$$
 */
package org.ow2.proactive.virtualizing.core;

import java.util.ArrayList;

import org.ow2.proactive.virtualizing.core.error.VirtualServiceException;


/**
 * A {@link VirtualMachineManager} is an object in charge of connect to a remote Virtual Appliances server.
 * Once it is connected to the remote server, one can ask it to give us a specific registered 
 * {@link VirtualMachine} or the list of all the registered one.
 * Every Object implementing {@link VirtualMachineManager} is supposed to automate network concerns 
 * (connection / disconnection / reconnection in case of network troubles).
 *
 */
public interface VirtualMachineManager {

    /**
     * This method must return all virtual machines that are registered within the server.
     * @return all the registered virtuals
     * @throws VirtualServiceException
     */
    public abstract ArrayList<? extends VirtualMachine> getVirtualMachines() throws VirtualServiceException;

    /**
     * Returns the virtual machine registered with the name parameter.
     * If a such virtuals isn't registered, an new {@link VirtualServiceException} must be thrown.
     * @param name the registered name of a virtual machine
     * @return the associated virtual machine
     * @throws VirtualServiceException if a such VM doesn't exist or if an issue occurs.
     */
    public abstract VirtualMachine getNewVM(String name) throws VirtualServiceException;

}
